#
# spec file for package ocaml-gen
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with ocaml_gen_testsuite
%define build_flavor %nil
%if "%build_flavor" == "testsuite"
%if %{without ocaml_gen_testsuite}
ExclusiveArch:  do-not-build
%else
ExclusiveArch:  aarch64 ppc64 ppc64le riscv64 s390x x86_64
%endif
%define nsuffix -testsuite
%else
%define nsuffix %nil
%endif

%define     pkg ocaml-gen
Name:           %pkg%nsuffix
Version:        1.1
Release:        2.3
%{?ocaml_preserve_bytecode}
Summary:        Simple, efficient iterators for OCaml
License:        BSD-2-Clause
Group:          Development/Languages/OCaml
URL:            https://opam.ocaml.org/packages/gen
Source0:        %pkg-%version.tar.xz
BuildRequires:  ocaml
BuildRequires:  ocaml-dune
BuildRequires:  ocaml-rpm-macros >= 20231101
%if 1
BuildRequires:  ocamlfind(seq)
%endif

%if "%build_flavor" == "testsuite"
BuildRequires:  ocamlfind(gen)
BuildRequires:  ocamlfind(ounit2)
BuildRequires:  ocamlfind(qcheck)
BuildRequires:  ocamlfind(qtest)
%endif

%description
Iterators for OCaml, both restartable and consumable.
The implementation keeps a good balance between simplicity and performance.


%package        devel
Summary:        Development files for %name
Group:          Development/Languages/OCaml
Requires:       %name = %version

%description    devel
The %name-devel package contains libraries and signature files for
developing applications that use %name.


%prep
%autosetup -p1 -n %pkg-%version

%build
dune_release_pkgs='gen'
%ocaml_dune_setup
%if "%build_flavor" == ""
%ocaml_dune_build
%endif

%install
%if "%build_flavor" == ""
%ocaml_dune_install
%ocaml_create_file_list
%endif

%if "%build_flavor" == "testsuite"
%check
%ocaml_dune_test
%endif

%if "%build_flavor" == ""
%files -f %name.files
%doc README.md

%files devel -f %name.files.devel

%endif

%changelog
* Mon Feb  5 2024 ohering@suse.de
- add disabled conditional around testsuite
* Sun May 21 2023 ohering@suse.de
- JaneStreet libraries are 64bit, this pkg depends on them
* Fri May  5 2023 ohering@suse.de
- Update to version 1.1
  See included CHANGELOG.md for details
* Mon Apr  4 2022 ohering@suse.de
- Update to version 1.0
  See included CHANGELOG.md for details
- Remove obsolete ocaml-gen.patch
* Tue Apr 13 2021 ohering@suse.de
- Use upstream repo, current ocaml-rpm-macros and ocaml-gen.patch
* Thu Jan 21 2021 ohering@suse.de
- remove dependency to ounit via _multibuild
* Thu Aug 20 2020 ohering@suse.de
- Update to version 0.5.3
  See included CHANGELOG.md for details
* Fri Nov  1 2019 ohering@suse.de
- Require current dune macros
- Use _service file
* Mon Sep 30 2019 ohering@suse.de
- use dune macros from ocaml-rpm-macros
* Tue May 21 2019 andy@onthewings.net
- New upstream release (0.5.2)
  * Transition to dune and opam 2.0.
  * Explicitly support BuckleScript.
* Mon Jan 15 2018 andy@onthewings.net
- Fixed license ID.
* Fri Jan 12 2018 andy@onthewings.net
- Initial spec of version 0.5.
